/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.util.swing;

import java.awt.Color;
import java.awt.Font;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import net.miginfocom.swing.MigLayout;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

/**
 * This panel is meant to be used to display error messages
 * TODO: Should be able to contain large messages use TextArea instead of JLabel for the message
 * @author Merijn Zengers
 */
@NbBundle.Messages({"ErrorPanel error large image=nl/cloudfarming/client/util/swing/error.png",
    "ErrorPanel error smal image=nl/cloudfarming/client/util/swing/error-badge.png",
    "ErrorPanel warning large image=nl/cloudfarming/client/util/swing/warning.png",
    "ErrorPanel warning smal image=nl/cloudfarming/client/util/swing/warning-badge.png"})
public class MessagePanel extends JPanel {

    private JLabel messageLabel;
    private JLabel errorIconLabel;
    private ImageIcon errorIcon;
    private ImageIcon warningIcon;
    private static final Color BACKGROUND_COLOR = Color.WHITE;
    public static final int SMAL_ICON = 0;
    public static final int LARGE_ICON = 1;
    public static final float SMAL_ICON_FONT_SIZE = 10;

    /**
     * <p>Construct a message panel with a icon size</p>
     * <p>Icon size options </br>
     * {@link MessagePanel#LARGE_ICON} for a large icon and normal sized font</br>
     * {@link MessagePanel#SMAL_ICON} for a small icon and a small sized font
     * @param iconSize 
     */
    public MessagePanel(int iconSize) {
        this.setLayout(new MigLayout("wrap 2, insets 0 0 0 0"));
        this.setBackground(BACKGROUND_COLOR);
        Font font;

        messageLabel = new JLabel();
        switch (iconSize) {
            case SMAL_ICON:
                errorIcon = new ImageIcon(ImageUtilities.loadImage(Bundle.ErrorPanel_error_smal_image()));
                warningIcon = new ImageIcon(ImageUtilities.loadImage(Bundle.ErrorPanel_warning_smal_image()));
                font = messageLabel.getFont().deriveFont(SMAL_ICON_FONT_SIZE);
                break;
            case LARGE_ICON:
                errorIcon = new ImageIcon(ImageUtilities.loadImage(Bundle.ErrorPanel_error_large_image()));
                warningIcon = new ImageIcon(ImageUtilities.loadImage(Bundle.ErrorPanel_warning_large_image()));
                font = messageLabel.getFont();
                break;
            default:
                errorIcon = new ImageIcon(ImageUtilities.loadImage(Bundle.ErrorPanel_error_large_image()));
                warningIcon = new ImageIcon(ImageUtilities.loadImage(Bundle.ErrorPanel_warning_large_image()));
                font = messageLabel.getFont();
        }
        messageLabel.setFont(font);
        errorIconLabel = new JLabel(errorIcon);

        this.add(errorIconLabel);
        this.add(messageLabel);
        this.setVisible(false);
    }

    /**
     * Set the error visible with a message
     *
     * @param errorMessage
     */
    public void setError(String errorMessage) {
        messageLabel.setText(errorMessage);
        errorIconLabel.setIcon(errorIcon);
        this.setVisible(true);
    }
    
    /**
     * Set the warning visible with a message
     * @param warningMessage 
     */
    public void setWarning(String warningMessage){
        messageLabel.setText(warningMessage);
        errorIconLabel.setIcon(warningIcon);
        this.setVisible(true);
    }

    /**
     * Set valid no errors or warnings panel will be hidden
     */
    public void setValid() {
        this.setVisible(false);
    }
}
