/*
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Contributors:
 *    johan - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.client.util.swing.beanbinding;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;
import java.util.Objects;
import org.jdesktop.beansbinding.Converter;

/**
 *
 * @author johan
 */
public class DateConverter extends Converter<Date, String>  {
    private final String pattern;
    private final Locale locale;

    public DateConverter(String pattern, Locale locale) {
        this.pattern = Objects.requireNonNull(pattern);
        this.locale = Objects.requireNonNull(locale);
    }
    
    public DateConverter(String pattern) {
        this(pattern, Locale.getDefault());
    }
    
    @Override
    public String convertForward(Date d) {
        return d == null ? "" : new SimpleDateFormat(pattern, locale).format(d);
    }

    @Override
    public Date convertReverse(String s) {
        if (s == null) { return null; }
        try {
            return new SimpleDateFormat(pattern, locale).parse(s);
        } catch (ParseException ex) {
            return null;
        }
    }
    
}
