/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.util.swing.beanbinding;

import org.jdesktop.beansbinding.Converter;

/**
 *<p>
 * Converts String to Integer If String cannot be converted set's the value to {@link Integer#MIN_VALUE}
 * This is used by the {@link IntegerValidator}
 *</p>
 * 
 * <p>
 * Usage:<br/>
 * 
 * yourBinding.setConverter(new IntegerConverter());<br/>
 * yourBinding.setValidator(new IntegerValidator());
 * </p>
 * 
 * @author Merijn Zengers
 */
public class IntegerConverter extends Converter<Integer, String> {

    /**
     * Converts Integer to String
     * @param arg
     * @return 
     */
    @Override
    public String convertForward(Integer arg) {
        return String.valueOf(arg);
    }

    /**
     * <p>Tries to convert String to double</p>
     * 
     * If conversion fails will return {@link Integer#MIN_VALUE} 
     * @param arg
     * @return 
     */
    @Override
    public Integer convertReverse(String arg) {
        Integer value;
        try {
            value = (arg == null || arg.isEmpty()) ? null : Integer.parseInt(arg);
        } catch (NumberFormatException ex) {
            value = Integer.MIN_VALUE;
        }
        return value;
    }
}
