/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.util.swing.beanbinding;

import org.jdesktop.beansbinding.Validator;
import org.openide.util.NbBundle;

/**
 * <p>Validates if a provided value is an Integer or at least a non fractionated
 * number</p> <p> Works in conjunction with {@link IntegerConverter}<br/> </p>
 * <p> Usage:<br/>
 *
 * yourBinding.setConverter(new IntegerConverter());<br/>
 * yourBinding.setValidator(new IntegerValidator()); </p>
 *
 * @author Merijn Zengers
 */
@NbBundle.Messages("IntegerValidator non integer value message=Should be a non fractionated number")
public class IntegerValidator extends Validator<Integer> {

    /**
     * Checks if the value passed is {@link Integer#MIN_VALUE} this indicates an
     * error occurred trying to convert user input to value
     *
     * @param arg
     * @return {@link Result} if passed in value is not equal to {@link Integer#MIN_VALUE}
     */
    @Override
    public Validator.Result validate(Integer arg) {
        if (arg != null) {
            if (arg == Integer.MIN_VALUE) {
                return new Validator.Result(null, Bundle.IntegerValidator_non_integer_value_message());
            }
        }
        return null;
    }
}
