/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.util.swing.button;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Insets;
import javax.swing.JButton;

/**
 * Button with an add icon displayed on it
 * @author Merijn Zengers
 */
public class ImageButton extends JButton {

    private Image image;
    private Image selectedImage;
    private Image disabledImage;
    private int w, h;
    private Color backGround;

    /**
     * Constructs an ImageButton with the specified image
     * Will take the height and with of the image as dimensions for the button
     * Any unfilled pixels will be filled with the supplied background
     * @param image The Image to draw
     * @param selectedImage the image to draw if the button is selected
     * @param backGround The Color of any unfilled pixels
     * @param toolTip the tool tip of the button
     */
    public ImageButton(Image image, Image selectedImage, Image disabledImage, Color backGround, String toolTip) {
        this.image = image;
        this.selectedImage = selectedImage;
        this.disabledImage = disabledImage;
        w = image.getWidth(null);
        h = image.getHeight(null) ;
        this.backGround = backGround;
        setBackground(backGround);
        this.setMargin(new Insets(0, 0, 0, 0));
        this.setToolTipText(toolTip);
        this.setBorderPainted(false);
    }

    @Override
    public void paint(Graphics g) {
        super.paintComponent(g);

        if(!isEnabled()){
            g.drawImage(disabledImage, 0, 0, backGround, null);
        } else if (isFocusPainted() && isFocusOwner() && selectedImage != null) {
            g.drawImage(selectedImage, 0, 0, backGround, null);
        } 
        else {
            g.drawImage(image, 0, 0, backGround, null);
        }
    }

    @Override
    public Dimension getPreferredSize() {
        return new Dimension(w, h);
    }

    @Override
    public Dimension getMinimumSize() {
        return new Dimension(w, h);
    }
}
