/**
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 * 
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 * 
 * The contents of this file are subject to the terms of either the GNU General
 * Public License Version 2 only ("GPL") or the Common Development and
 * Distribution License("CDDL") (collectively, the "License"). You may not use
 * this file except in compliance with the License. You can obtain a copy of the
 * License at http://www.netbeans.org/cddl-gplv2.html or
 * nbbuild/licenses/CDDL-GPL-2-CP. See the License for the specific language
 * governing permissions and limitations under the License. When distributing
 * the software, include this License Header Notice in each file and include the
 * License file at nbbuild/licenses/CDDL-GPL-2-CP. Oracle designates this
 * particular file as subject to the "Classpath" exception as provided by Oracle
 * in the GPL Version 2 section of the License file that accompanied this code.
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 * 
 * If you wish your version of this file to be governed by only the CDDL or only
 * the GPL Version 2, indicate your decision by adding "[Contributor] elects to
 * include this software in this distribution under the [CDDL or GPL Version 2]
 * license." If you do not indicate a single choice of license, a recipient has
 * the option to distribute your version of this file under either the CDDL, the
 * GPL Version 2 or to extend the choice of license to its licensees as provided
 * above. However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is made
 * subject to such option by the copyright holder.
 * 
 * Portions Copyrighted 2012 AgroSense
 */
package nl.cloudfarming.client.util.swing.editors;

import java.awt.*;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyEditor;
import javax.swing.JColorChooser;
import javax.swing.JPanel;
import javax.swing.colorchooser.ColorSelectionModel;
import javax.swing.colorchooser.DefaultColorSelectionModel;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import org.openide.util.NbBundle;

/**
 * A property editor for Color class.
 *
 */
@NbBundle.Messages({"ColorEditor name=Color picker",
    "ColorEditor null color display text=null",
    "ColorEditor color display text red=red",
    "ColorEditor color display text green=green",
    "ColorEditor color display text blue=blue"})
public final class ColorEditor implements PropertyEditor{

    private static final String PROP_COLOR = "color";
    private Color color;
    private PropertyChangeSupport propertyChangeSupport;

    /**
     * Creates color editor.
     */
    public ColorEditor() {
        propertyChangeSupport = new PropertyChangeSupport(this);
    }

    /**
     * Gets value.
     *
     * @return
     * <code>Color</code> value or
     * <code>null</code>
     */
    @Override
    public Object getValue() {
        return color;
    }

    /**
     * Sets value.
     *
     * @param object object to set, accepts
     * <code>Color</code>
     */
    @Override
    public void setValue(Object object) {
        Color oldValue = color;
        if (object != null) {
            if (object instanceof Color) {
                color = (Color) object;
            }
        } else {
            color = null;
        }

        propertyChangeSupport.firePropertyChange(PROP_COLOR, oldValue, color);
    }

    /**
     * Gets value as text.
     */
    @Override
    public String getAsText() {
        if (color == null) {
            return Bundle.ColorEditor_null_color_display_text();
        }
        StringBuilder colorTextBuilder = new StringBuilder("[");
        colorTextBuilder.append(Bundle.ColorEditor_color_display_text_red());
        colorTextBuilder.append("=");
        colorTextBuilder.append(color.getRed());
        colorTextBuilder.append(", ");
        colorTextBuilder.append(Bundle.ColorEditor_color_display_text_green());
        colorTextBuilder.append("=");
        colorTextBuilder.append(color.getGreen());
        colorTextBuilder.append(", ");
        colorTextBuilder.append(Bundle.ColorEditor_color_display_text_blue());
        colorTextBuilder.append("=");
        colorTextBuilder.append(color.getBlue());
        colorTextBuilder.append("]");
        return colorTextBuilder.toString();
    }

    /**
     * Sets value as text.
     */
    @Override
    public void setAsText(String text) throws IllegalArgumentException {
        //Do nothing not supported
    }

    /**
     * Indicates whether this editor is paintable.
     *
     * @return
     * <code>true</code>
     */
    @Override
    public boolean isPaintable() {
        return true;
    }

    /**
     * Paints the current value.
     */
    @Override
    public void paintValue(Graphics g, Rectangle rectangle) {
        int px;

        if (color != null) {
            g.drawRect(rectangle.x, rectangle.y + rectangle.height / 2 - 5, 10, 10);
            g.setColor(color);
            g.fillRect(rectangle.x + 1, rectangle.y + rectangle.height / 2 - 4, 9, 9);
            px = 18;
        } else {
            px = 0;
        }

        FontMetrics fm = g.getFontMetrics();
        g.drawString(getAsText(), rectangle.x + px, rectangle.y
                + (rectangle.height - fm.getHeight()) / 2 + fm.getAscent());
    }

    /**
     * Indicates whether this editor supports custom editing.
     *
     * @return
     * <code>true</code>
     */
    @Override
    public boolean supportsCustomEditor() {
        return true;
    }

    /**
     * Gets custom editor.
     *
     * @return
     * <code>ColorChooser</code> instance
     */
    @Override
    public Component getCustomEditor() {
        JColorChooser chooser = new JColorChooser(new DefaultColorSelectionModel(Color.white));
        return new ColorEditor.ColorChooser(this, chooser);
    }

    /**
     * Adds property change listener.
     */
    @Override
    public void addPropertyChangeListener(PropertyChangeListener propertyChangeListener) {
        propertyChangeSupport.addPropertyChangeListener(propertyChangeListener);
    }

    /**
     * Removes property change listener.
     */
    @Override
    public void removePropertyChangeListener(PropertyChangeListener propertyChangeListener) {
        propertyChangeSupport.removePropertyChangeListener(propertyChangeListener);
    }

    /**
     * Not supported
     *
     * @return
     */
    @Override
    public String getJavaInitializationString() {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    /**
     * returns null
     *
     * @return
     */
    @Override
    public String[] getTags() {
        return null;
    }

    /**
     * Panel used as custom property editor.
     */
    private static class ColorChooser extends JPanel implements ChangeListener {

        /**
         * Color property editor
         */
        private final ColorEditor editor;
        /**
         * Reference to model which holds the color selected in the color
         * chooser
         */
        private final ColorSelectionModel selectionModel;
        static final long serialVersionUID = -6230228701104365037L;

        /**
         * Creates new
         * <code>ColorChooser</code>.
         */
        public ColorChooser(final ColorEditor editor,
                final JColorChooser chooser) {
            this.editor = editor;
            selectionModel = chooser.getSelectionModel();
            setLayout(new BorderLayout());
            add(chooser, BorderLayout.CENTER);
            chooser.setColor((Color) editor.getValue());
            selectionModel.addChangeListener(this);

            getAccessibleContext().setAccessibleDescription(Bundle.ColorEditor_name());
        }

        /**
         * Overrides superclass method. Adds removing of change listener.
         */
        @Override
        public void removeNotify() {
            super.removeNotify();
            selectionModel.removeChangeListener(this);
        }

        /**
         * Overrides superclass method. Adds 50 pixels to each side.
         */
        @Override
        public Dimension getPreferredSize() {
            Dimension s = super.getPreferredSize();
            return new Dimension(s.width + 50, s.height + 10);
        }

        /**
         * Implements
         * <code>ChangeListener</code> interface
         */
        @Override
        public void stateChanged(ChangeEvent evt) {
            editor.setValue(selectionModel.getSelectedColor());
        }
    }
}
